EXPORTS
	??1CVwsSessionWrapper@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CVwsSessionWrapper::~CVwsSessionWrapper(void)
	?ActivateView@CVwsSessionWrapper@@QAEHABVTVwsViewId@@VTUid@@ABVTDesC8@@@Z @ 2 NONAME ; public: int __thiscall CVwsSessionWrapper::ActivateView(class TVwsViewId const &,class TUid,class TDesC8 const &)
	?AddView@CVwsSessionWrapper@@QAEHABVTVwsViewId@@@Z @ 3 NONAME ; public: int __thiscall CVwsSessionWrapper::AddView(class TVwsViewId const &)
	?DeactivateActiveView@CVwsSessionWrapper@@QAEHXZ @ 4 NONAME ; public: int __thiscall CVwsSessionWrapper::DeactivateActiveView(void)
	?NewL@CVwsSessionWrapper@@SAPAV1@AAVMVwsSessionWrapperObserver@@@Z @ 5 NONAME ; public: static class CVwsSessionWrapper * __cdecl CVwsSessionWrapper::NewL(class MVwsSessionWrapperObserver &)
	?NewL@CVwsSessionWrapper@@SAPAV1@XZ @ 6 NONAME ; public: static class CVwsSessionWrapper * __cdecl CVwsSessionWrapper::NewL(void)
	?NewLC@CVwsSessionWrapper@@SAPAV1@AAVMVwsSessionWrapperObserver@@@Z @ 7 NONAME ; public: static class CVwsSessionWrapper * __cdecl CVwsSessionWrapper::NewLC(class MVwsSessionWrapperObserver &)
	?NewLC@CVwsSessionWrapper@@SAPAV1@XZ @ 8 NONAME ; public: static class CVwsSessionWrapper * __cdecl CVwsSessionWrapper::NewLC(void)
	?QueueAsyncRequest@CVwsSessionWrapper@@QAEXXZ @ 9 NONAME ; public: void __thiscall CVwsSessionWrapper::QueueAsyncRequest(void)
	?RemoveView@CVwsSessionWrapper@@QBEHABVTVwsViewId@@@Z @ 10 NONAME ; public: int __thiscall CVwsSessionWrapper::RemoveView(class TVwsViewId const &)const 
	?RequestCustomMessage@CVwsSessionWrapper@@QBEHAAVTDes8@@@Z @ 11 NONAME ; public: int __thiscall CVwsSessionWrapper::RequestCustomMessage(class TDes8 &)const 
	?StartApp@CVwsSessionWrapper@@QAEHVTUid@@@Z @ 12 NONAME ; public: int __thiscall CVwsSessionWrapper::StartApp(class TUid)
	?StartViewServer@CVwsSessionWrapper@@SAHAAVMVwsAppStarter@@@Z @ 13 NONAME ; public: static int __cdecl CVwsSessionWrapper::StartViewServer(class MVwsAppStarter &)
	?ActivateViewViaViewEvent@CVwsSessionWrapper@@QAEHABVTVwsViewIdAndMessage@@@Z @ 14 NONAME ; public: int __thiscall CVwsSessionWrapper::ActivateViewViaViewEvent(class TVwsViewIdAndMessage const &)
	?NotifyNextDeactivation@CVwsSessionWrapper@@QAEHABVTVwsViewId@@@Z @ 15 NONAME ; public: int __thiscall CVwsSessionWrapper::NotifyNextDeactivation(class TVwsViewId const &)
	?SetSystemDefaultView@CVwsSessionWrapper@@QAEHABVTVwsViewId@@@Z @ 16 NONAME ; public: int __thiscall CVwsSessionWrapper::SetSystemDefaultView(class TVwsViewId const &)
	?ShutdownViewServer@CVwsSessionWrapper@@QAEHXZ @ 17 NONAME ; public: int __thiscall CVwsSessionWrapper::ShutdownViewServer(void)
	?NotifyNextActivation@CVwsSessionWrapper@@QAEHXZ @ 18 NONAME ; public: int __thiscall CVwsSessionWrapper::NotifyNextActivation(void)
	?SetSystemDefaultView@CVwsSessionWrapper@@QAEHABVTVwsViewId@@H@Z @ 19 NONAME ; public: int __thiscall CVwsSessionWrapper::SetSystemDefaultView(class TVwsViewId const &,int)
	?NotifyNextActivation@CVwsSessionWrapper@@QAEHABVTVwsViewId@@@Z @ 20 NONAME ; public: int __thiscall CVwsSessionWrapper::NotifyNextActivation(class TVwsViewId const &)
	?NotifyNextDeactivation@CVwsSessionWrapper@@QAEHXZ @ 21 NONAME ; public: int __thiscall CVwsSessionWrapper::NotifyNextDeactivation(void)
	?SetDefaultView@CVwsSessionWrapper@@QBEHABVTVwsViewId@@@Z @ 22 NONAME ; public: int __thiscall CVwsSessionWrapper::SetDefaultView(class TVwsViewId const &)const 
	?SetDefaultView@CVwsSessionWrapper@@QBEHABVTVwsViewId@@H@Z @ 23 NONAME ; public: int __thiscall CVwsSessionWrapper::SetDefaultView(class TVwsViewId const &,int)const 
	?CreateActivateViewEvent@CVwsSessionWrapper@@QAEHABVTVwsViewId@@VTUid@@ABVTDesC8@@@Z @ 24 NONAME ; public: int __thiscall CVwsSessionWrapper::CreateActivateViewEvent(class TVwsViewId const &,class TUid,class TDesC8 const &)
	?SetClientRequestTimeOut@CVwsSessionWrapper@@QAEHVTTimeIntervalMicroSeconds32@@@Z @ 25 NONAME ; public: int __thiscall CVwsSessionWrapper::SetClientRequestTimeOut(class TTimeIntervalMicroSeconds32)
	?SetServerEventTimeOut@CVwsSessionWrapper@@QAEHVTTimeIntervalMicroSeconds32@@@Z @ 26 NONAME ; public: int __thiscall CVwsSessionWrapper::SetServerEventTimeOut(class TTimeIntervalMicroSeconds32)
	?EnableServerEventTimeOut@CVwsSessionWrapper@@QAEHH@Z @ 27 NONAME ; public: int __thiscall CVwsSessionWrapper::EnableServerEventTimeOut(int)
	?GetSystemDefaultView@CVwsSessionWrapper@@QAEHAAVTVwsViewId@@@Z @ 28 NONAME ; public: int __thiscall CVwsSessionWrapper::GetSystemDefaultView(class TVwsViewId &)
	?CheckSourceOfViewSwitch@CVwsSessionWrapper@@QAEHAAHABVTSecurityPolicy@@PBD@Z @ 29 NONAME ; int CVwsSessionWrapper::CheckSourceOfViewSwitch(int &, class TSecurityPolicy const &, char const *)
	?EnableServerBlankScreen@CVwsSessionWrapper@@QAEHH@Z @ 30 NONAME ; int CVwsSessionWrapper::EnableServerBlankScreen(int)
	?EnableExternalViewSwitches@CVwsSessionWrapper@@QAEHH@Z @ 31 NONAME ; int CVwsSessionWrapper::SetProtected(int)
	?ActivateView@CVwsSessionWrapper@@QAEXABVTVwsViewId@@VTUid@@ABVTDesC8@@AAVTRequestStatus@@@Z @ 32 NONAME ; void CVwsSessionWrapper::ActivateView(class TVwsViewId const &, class TUid, class TDesC8 const &, class TRequestStatus &)
	?SetCrossCheckUid@CVwsSessionWrapper@@QAEHABVTUid@@@Z @ 33 NONAME ; int CVwsSessionWrapper::SetCrossCheckUid(class TUid const &)
	?DeactivateActiveViewIfOwnerMatch@CVwsSessionWrapper@@QAEHXZ @ 34 NONAME ; int CVwsSessionWrapper::DeactivateActiveViewIfOwnerMatch(void)
	?SetWindowBackgroundColor@CVwsSessionWrapper@@QAEHABVTRgb@@@Z @ 35 NONAME ; int CVwsSessionWrapper::SetWindowBackgroundColor(class TRgb const &)
	?ActivateView@CVwsSessionWrapper@@QAEHABVTVwsViewId@@VTUid@@ABVTDesC8@@H@Z @ 36 NONAME ; int CVwsSessionWrapper::ActivateView(class TVwsViewId const &, class TUid, class TDesC8 const &, int)
	?ActivateView@CVwsSessionWrapper@@QAEXABVTVwsViewId@@VTUid@@ABVTDesC8@@AAVTRequestStatus@@H@Z @ 37 NONAME ; void CVwsSessionWrapper::ActivateView(class TVwsViewId const &, class TUid, class TDesC8 const &, class TRequestStatus &, int)
	?CreateActivateViewEvent@CVwsSessionWrapper@@QAEHABVTVwsViewId@@VTUid@@ABVTDesC8@@H@Z @ 38 NONAME ; int CVwsSessionWrapper::CreateActivateViewEvent(class TVwsViewId const &, class TUid, class TDesC8 const &, int)
	?GetCurrentActiveViewInSystem@CVwsSessionWrapper@@QAEHAAVTVwsViewId@@@Z @ 39 NONAME ; int CVwsSessionWrapper::GetCurrentActiveViewInSystem(class TVwsViewId &)

